summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAmritanshu <a.pandia1@samsung.com>2020-06-06 01:48:53 +0530
committerAmritanshu <a.pandia1@samsung.com>2020-06-09 21:19:17 +0530
commit8aa0eba03b9c80213cb0820871b803507abf455e (patch)
tree35efb4b1955dbf70dbe5d8d532d3ac3238744402
parent4941ce98df703d9bf11fd9d91043b52eab74a43a (diff)
downloadapptray-widget-tizen_6.0.tar.gz
apptray-widget-tizen_6.0.tar.bz2
apptray-widget-tizen_6.0.zip
Change-Id: I9d32b70f4fb4050a2bf23f5bf3a4c60a05329810 Signed-off-by: Amritanshu <a.pandia1@samsung.com>
-rwxr-xr-xapptray-widget-app/CMakeLists.txt5
-rwxr-xr-xapptray-widget-app/src/apptray_wgt_app.c2
-rwxr-xr-xapptray-widget/CMakeLists.txt1
-rwxr-xr-x[-rw-r--r--]apptray-widget/inc/apptray_widget_common_defines.h4
-rwxr-xr-xapptray-widget/src/apptray_widget.c12
5 files changed, 10 insertions, 14 deletions
diff --git a/apptray-widget-app/CMakeLists.txt b/apptray-widget-app/CMakeLists.txt
index bb8cd79..cea0bad 100755
--- a/apptray-widget-app/CMakeLists.txt
+++ b/apptray-widget-app/CMakeLists.txt
@@ -3,7 +3,7 @@ PROJECT(apptray-widget C)
SET(SRCS
src/apptray_wgt_app.c
- src/apptray_wgt_app_key.c
+ src/apptray_wgt_app_key_event_provider.c
src/apptray_wgt_app_utils.c
src/apptray_wgt_app_item_info.c
src/apptray_wgt_app_accessibility_utils.c
@@ -49,11 +49,8 @@ pkg_check_modules(pkgs REQUIRED
elementary
eina
evas
- widget_viewer
widget_viewer_evas
widget_service
- pkgmgr
- pkgmgr-info
efl-extension
vconf
appsvc
diff --git a/apptray-widget-app/src/apptray_wgt_app.c b/apptray-widget-app/src/apptray_wgt_app.c
index 5b0416a..02e29a5 100755
--- a/apptray-widget-app/src/apptray_wgt_app.c
+++ b/apptray-widget-app/src/apptray_wgt_app.c
@@ -31,7 +31,7 @@
#include "apptray_wgt_app_key_event_provider.h"
#include "apptray_wgt_app_log.h"
-#define ATW_DEFAULT_APP_ORDER "org.tizen.apptray-widget-app org.tizen.alarm org.tizen.w-phone org.tizen.watch-setting"
+#define ATW_DEFAULT_APP_ORDER "org.tizen.apptray-widget-app org.tizen.w-phone org.tizen.watch-setting"
#define ATW_APP_WIDGET_CONTENT_KEY "org.tizen.apptray-widget"
diff --git a/apptray-widget/CMakeLists.txt b/apptray-widget/CMakeLists.txt
index 81c68ad..4cfeb92 100755
--- a/apptray-widget/CMakeLists.txt
+++ b/apptray-widget/CMakeLists.txt
@@ -51,7 +51,6 @@ pkg_check_modules(pkgs REQUIRED
elementary
eina
evas
- widget_viewer
widget_viewer_evas
widget_service
efl-extension
diff --git a/apptray-widget/inc/apptray_widget_common_defines.h b/apptray-widget/inc/apptray_widget_common_defines.h
index 9956681..519720b 100644..100755
--- a/apptray-widget/inc/apptray_widget_common_defines.h
+++ b/apptray-widget/inc/apptray_widget_common_defines.h
@@ -29,10 +29,10 @@
#define ATW_APP_LAUNCH_KEY "launch_apps"
#define ATW_WHOME_APP_CONTROL "home_op"
-#define ATW_DEFAULT_APP_ORDER "org.tizen.apptray-widget-app org.tizen.alarm org.tizen.w-phone org.tizen.watch-setting"
+#define ATW_DEFAULT_APP_ORDER "org.tizen.apptray-widget-app org.tizen.w-phone org.tizen.watch-setting"
#define ATW_MAX_BADGE_COUNT 999
-#define ATW_SLOTS_MAX_COUNT 4
+#define ATW_SLOTS_MAX_COUNT 3
#define ATW_BUFF_SIZE_SMALL 32
#define ATW_BUFF_SIZE_MIDDLE 64
diff --git a/apptray-widget/src/apptray_widget.c b/apptray-widget/src/apptray_widget.c
index f6ad857..9c59e1a 100755
--- a/apptray-widget/src/apptray_widget.c
+++ b/apptray-widget/src/apptray_widget.c
@@ -28,7 +28,7 @@
#include "apptray_widget_utils.h"
#include "apptray_widget_accessibility_utils.h"
-#define ATW_SLOT_INDEX_BUFF_SIZE 10
+#define ATW_SLOT_INDEX_BUFF_SIZE 17
#define ATW_BUNDLE_KEY_SHORTCUT_LIST "shortcut_list"
@@ -531,7 +531,7 @@ static void _update_slot_access_object_info(_slot_h slot)
* @brief Sets slot to main layout
* @param[in] instance Instance handle
* @param[in] appid Application id to display slot
* @param[in] index Slot index
* @return true on success, otherwise false
*/
static bool _set_slot(_instance_h instance, const char *appid, int pos)
@@ -544,7 +544,7 @@ static bool _set_slot(_instance_h instance, const char *appid, int pos)
char *label = NULL;
char *icon_path_tmp = NULL;
- _D("Try update slot [%d]", index + 1);
+ _D("Try update slot [%d]", pos + 1);
if (!appid || !strcmp(appid, "empty")) {
_D("appid to set is empty");
@@ -620,7 +620,7 @@ static bool _set_slot(_instance_h instance, const char *appid, int pos)
if (app_info)
app_info_destroy(app_info);
- _D("Slot [%d] was added", index + 1);
+ _D("Slot [%d] was added", pos + 1);
return true;
@@ -634,7 +634,7 @@ fail_return:
if (app_info)
app_info_destroy(app_info);
- _D("Slot [%d] was not added", index + 1);
+ _D("Slot [%d] was not added", pos + 1);
return false;
}
@@ -653,7 +653,7 @@ static void _reset_slot(_instance_h instance, int index)
FREE(instance->slot[index].label);
FREE(instance->slot[index].pkgid);
- char index_str[10] = { 0 };
+ char index_str[ATW_SLOT_INDEX_BUFF_SIZE] = { 0 };
snprintf(index_str, sizeof(index_str), "slot_%d", index + 1);
elm_object_part_content_unset(instance->layout, index_str);
@@ -531,7 +531,7 @@ static void _update_slot_access_object_info(_slot_h slot)
* @param[in] instance Instance handle
* @param[in] appid Application id to display slot
- * @param[in] index Slot index
+ * @param[in] pos Slot index
* @return true on success, otherwise false
*/